
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.17.0',
    'branch_nick': 'feature-0-1_17_0_preparation',
    'revision_id': 'c2c0fc87f25684a66da95425f463a39e2109fa9e',
    'revno': 6769
}
